@@ -1,6 +1,5 @@
 test_that("Regularization works", {
   skip_on_cran()
-  skip_on_ci()
   local_edition(2)
   d <- subset(pcod, year >= 2015)
   d$depth_scaled <- as.numeric(scale(d$depth_scaled))
@@ -31,7 +30,6 @@ test_that("Regularization works", {
 
 test_that("A time-varying model fits and predicts appropriately", {
   skip_on_cran()
-  skip_on_ci()
   local_edition(2)
   # SEED <- 42
   # set.seed(SEED)
@@ -84,7 +82,6 @@ test_that("Year indexes get created correctly", {
 
 test_that("A spatially varying coefficient model fits", {
   skip_on_cran()
-  skip_on_ci()
   d <- subset(pcod, year >= 2011) # subset for speed
   pcod_spde <- make_mesh(d, c("X", "Y"), cutoff = 30)
   d$scaled_year <- (d$year - mean(d$year)) / sd(d$year)
@@ -101,7 +98,6 @@ test_that("A spatially varying coefficient model fits", {
 test_that("SPDE as generated by make_mesh is consistent", {
   set.seed(42)
   skip_on_cran()
-  skip_on_ci()
   set.seed(1)
   local_edition(2)
   x <- stats::runif(70, -1, 1)
@@ -173,7 +169,6 @@ test_that("SPDE as generated by make_mesh is consistent", {
 
 test_that("profile option works", {
   skip_on_cran()
-  skip_on_ci()
   d <- subset(pcod, year == 2013)
   pcod_spde <- make_mesh(d, c("X", "Y"), cutoff = 10)
   mp <- sdmTMB(density ~ depth_scaled + depth_scaled2,
@@ -192,7 +187,6 @@ test_that("profile option works", {
 
 test_that("The mapping off spatial and spatiotemporal fields works.", {
   skip_on_cran()
-  skip_on_ci()
   d <- subset(pcod, year >= 2013)
   pcod_spde <- make_mesh(d, c("X", "Y"), cutoff = 50)
   m <- sdmTMB(density ~ 0 + as.factor(year),
@@ -251,7 +245,6 @@ test_that("Large coordinates cause a warning.", {
 
 test_that("Random walk fields work", {
   skip_on_cran()
-  skip_on_ci()
   d <- subset(pcod, year >= 2013)
   pcod_spde <- make_mesh(d, c("X", "Y"), cutoff = 15)
   m_rw <- sdmTMB(density ~ 1,
@@ -281,7 +274,6 @@ test_that("Random walk fields work", {
 
 test_that("start works", {
   skip_on_cran()
-  skip_on_ci()
 
     expect_error({
       m2 <- sdmTMB(density ~ poly(depth, 2),
@@ -300,7 +292,6 @@ test_that("start works", {
 
 test_that("Multiple SVC works", {
   skip_on_cran()
-  skip_on_ci()
 
   mesh <- make_mesh(pcod, c("X", "Y"), cutoff = 15)
 
@@ -324,7 +315,6 @@ test_that("Multiple SVC works", {
 
 test_that("More esoteric prediction options work", {
   skip_on_cran()
-  skip_on_ci()
   fit <- sdmTMB(
     density ~ depth_scaled,
     data = pcod_2011, mesh = pcod_mesh_2011,
@@ -369,7 +359,6 @@ test_that("More esoteric prediction options work", {
 
 test_that("update() works", {
   skip_on_cran()
-  skip_on_ci()
   fit <- sdmTMB(
     density ~ depth_scaled,
     data = pcod_2011, mesh = pcod_mesh_2011,
@@ -518,4 +507,29 @@ test_that("Time with an NA gets flagged", {
   }, regexp = "time")
 })
 
+test_that("Prediction outside fitted coordinates gets warned about #285", {
+  fit <- sdmTMB(
+    present ~ 1,
+    family = binomial(),
+    data = pcod_2011,
+    mesh = pcod_mesh_2011
+  )
+  nd <- qcs_grid
+  range(nd$X)
+  nd$X <- nd$X * 10
+  range(nd$X)
+  expect_warning(p <- predict(fit, newdata = nd), regexp = "coordinates")
+
+  nd <- qcs_grid
+  nd$X <- nd$X / 10
+  expect_warning(p <- predict(fit, newdata = nd), regexp = "coordinates")
+
+  nd <- qcs_grid
+  nd$Y <- nd$Y / 10
+  expect_warning(p <- predict(fit, newdata = nd), regexp = "coordinates")
+
+  nd <- qcs_grid
+  nd$Y <- nd$Y * 10
+  expect_warning(p <- predict(fit, newdata = nd), regexp = "coordinates")
+})
 
